*******************************************************************************
****** In this do-file, we conduct an alternative approach to specify the confidence 
****** intervals in our main regression tables, Table 2 and Table 4. 
****** We discuss the details in the Online appendix. 
*******************************************************************************

set more off
clear

use Data\Compiled\pointestbaseline.dta

mkmat parall1 parall2 parall3, matrix(meanests)

clear

use Data\Compiled\pointestgi.dta

mkmat parall1 parall2 parall3, matrix(meanestsgi)


*** load old confidence intervals

clear

use Data\Compiled\CI_main.dta

mkmat confinal1 confinal2 confinal3, matrix(confidence)

clear

use Data\Compiled\CI_maingi.dta

mkmat confinal1 confinal2 confinal3, matrix(confidencegi)

clear

**** Start Analysis

use Data\Compiled\datasnl-final.dta


gen MA_GI=0 

replace MA_GI=1 if state=="ME" | state=="NY"  | state=="VT" | state=="WA" | state=="MA" 


encode state, gen(stateid)



**** Normalize year to 2007

gen yearold=year

replace year=year-2007


sort state year


*** demean

gen prem_ind_res=.


levelsof stateid, local(stateidlist)




 foreach s of local stateidlist {
 quietly sum prem_per_year_ind if stateid==`s' & yearold<2006
 
 replace prem_ind_res=prem_per_year_ind-r(mean) if stateid==`s'
 
}
***


sort state year


gen lgac=log(prov_health_serv_incur_ind_year)

gen lgprem=log(prem_per_year_ind)


gen mem_mo_ind_rel=.

**** For all States

levelsof state, local(levels) 

foreach l of local levels {

quietly sum mem_mo_ind if yearold>2007 & yearold<=2010 & state=="`l'"

local ypostma=r(mean)

replace mem_mo_ind_rel=mem_mo_ind/`ypostma'*insurance300post if state=="`l'" 


}
***

**** Adjust Other States if estimate exceeds 120%



by stateid, sort: egen endcov_share=max(mem_mo_ind_rel)

replace mem_mo_ind_rel=mem_mo_ind_rel/endcov_share if endcov_share>1.2


**** Merge Abadie Weights

gen statenr=stateid

merge m:1 statenr using Data\Compiled\abadieweights.dta

gen MAduring=0
replace MAduring=1 if MA==1 & (yearold==2006 | yearold==2007)

gen MAafter=0
replace MAafter=1 if MA==1 & yearold>2007


*** replace abadie weight from Missing to 1 for Massachusetts 
*** (the magnitude has no effect on estimates but needs to be nonmissing)

replace wallall2=1 if MA==1
replace wallgi2=1 if MA==1




quietly tab yearold, gen(yearfe_)


***** All

gen during=0

replace during=1 if yearold==2006 | yearold==2007


gen after=0

replace after=1 if yearold>2007

******
*** Alternative Bootstrap
******

xtset stateid

quietly xtreg lgac MAafter MAduring MA after during  [aw=wallall2] if yearold<2011, cluster(stateid) fe

predict res_claim, e

quietly xtreg lgprem MAafter MAduring MA after during  [aw=wallall2] if yearold<2011, cluster(stateid) fe

predict res_prem, e

quietly xtreg mem_mo_ind_rel MAafter MAduring MA after during  [aw=wallall2] if yearold<2011, cluster(stateid) fe

predict res_enr, e


**** Guaranteed Issue


quietly xtreg lgac MAafter MAduring MA after during  [aw=wallgi2] if yearold<2011, cluster(stateid) fe

predict res_claimgi, e

quietly xtreg lgprem MAafter MAduring MA after during  [aw=wallgi2] if yearold<2011, cluster(stateid) fe

predict res_premgi, e

quietly xtreg mem_mo_ind_rel MAafter MAduring MA after during  [aw=wallgi2] if yearold<2011, cluster(stateid) fe

predict res_enrgi, e


*** gen squared residuals

keep if yearold>2007 & yearold<2011

drop if MA==1

by yearold, sort: gen counteryear=_n

by state, sort: gen counterstate=_n


****


local vars ""enr" "prem" "claim""
local varsgi ""enrgi" "premgi" "claimgi"" 
local varsall ""enr" "prem" "claim" "enrgi" "premgi" "claimgi"" 

foreach var of local vars {

gen weightres_`var'=wallall2*res_`var' 

}
****

foreach var of local varsgi {

gen weightres_`var'=wallgi2*res_`var' 

}
foreach var of local varsall {

*** epsilon_i*epsilon_i

gen res2_`var'=res_`var'*res_`var'

*** average (sum weights) across control states: sum(wi*epsiloni)

by yearold,sort: egen sumweightres_`var'=sum(weightres_`var')

*** square it

gen sumweightres2_`var'=sumweightres_`var'*sumweightres_`var'

*** average over years (MA equivalent)

by state, sort: egen avgres2_`var'=mean(res2_`var')

}
******

*** Produce Table


local i=1
local j=1


# delimit ;
cap file close f ;
file open f using "${tabout}Data\Compiled\Tables\did-table-boot_extension.tex" , write replace ;
file write f 

"{\begin{tabular}{lccc}" _n
"\hline\hline" _n

"&" _tab "(1)" _tab "&" _tab "(2)" _tab "&" _tab "(3)" _tab "\\" _n
 
"Baseline:" _tab "&" _tab "Coverage" _tab "&" _tab "Log Premium" _tab "&" _tab "Log Claim Exp" _tab "\\" _n

"\hline" _n ;

# delimit cr




foreach row of numlist 1 2 {



if `row'==1 {


file write f "$\gamma^k \ $   MA*After"  _tab 

**** standard deviation

*** control component (2nd variance term)

foreach var of local vars {

quietly sum sumweightres2_`var' if counteryear==1

local var1=`r(mean)'

quietly sum avgres2_`var' if counterstate==1 [aw=wallall2]

local var2=`r(mean)'

local sd=sqrt((`var1'+`var2')/3)

local treat=meanests[1,`i']


**** stars

  local s=""
  if (`treat'-(1.645*`sd'))*(`treat'+(1.645*`sd'))>0 local s="$^{*\ \ }$"
  if (`treat'-(1.96*`sd'))*(`treat'+(1.96*`sd'))>0 local s="$^{**\ }$"
  if (`treat'-(2.326*`sd'))*(`treat'+(2.326*`sd'))>0 local s="$^{***}$"
  


file write f "&" _tab %5.3f (meanests[1,`i']) "`s'"

								

								
local i=`i'+1
						}
						
file write f "\\" _n
								
			}
			
local i=1

if `row'==2 {   

*** standard errors

foreach var of local vars {

quietly sum sumweightres2_`var' if counteryear==1

local var1=`r(mean)'

quietly sum avgres2_`var' if counterstate==1 [aw=wallall2]

local var2=`r(mean)'

local sd=sqrt((`var1'+`var2')/3)

local low=meanests[1,`i']-(1.96*`sd')
local up=meanests[1,`i']+(1.96*`sd')

file write f "&" _tab "[" %4.3f (`low') ", " %4.3f (`up') "]"

local i=`i'+1
						}
							
file write f "\\" _n

			}
							


						  }
					  
***** 

file write f "\hline" _n   _tab

**** Add baseline CI  

*** standard errors

file write f "Bootstrapped Percentiles:" _tab

foreach i of numlist 1/3 {

file write f  "&" _tab "[" %4.3f (confidence[`i',1]) ", " %4.3f (confidence[`i',2]) "]" _tab 
						}

***

file write f "\\" _n

file write f "Bootstrapped SD:" _tab

foreach i of numlist 1/3 {

local low=meanests[1,`i']-(1.96*confidence[`i',3])
local up=meanests[1,`i']+(1.96*confidence[`i',3])

file write f  "&" _tab "[" %4.3f (`low') ", " %4.3f (`up') "]" _tab 
						}

***

file write f "\\" _n



file write f "\hline\hline" _n   _tab

file write f "\\" _n

file write f "\hline" _n   _tab

# delimit ;

file write f 

"&" _tab "(1)" _tab "&" _tab "(2)" _tab "&" _tab "(3)" _tab "\\" _n
 
"Guaranteed Issue:" _tab "&" _tab "Coverage" _tab "&" _tab "Log Premium" _tab "&" _tab "Log Claim Exp" _tab "\\" _n

"\hline" _n ;

# delimit cr


local i=1

foreach row of numlist 1 2 {



if `row'==1 {


file write f "$\gamma^k \ $   MA*After"  _tab 

**** standard deviation

*** control component (2nd variance term)

foreach var of local varsgi {

quietly sum sumweightres2_`var' if counteryear==1

local var1=`r(mean)'

quietly sum avgres2_`var' if counterstate==1 [aw=wallall2]

local var2=`r(mean)'

local sd=sqrt((`var1'+`var2')/3)

local treat=meanestsgi[1,`i']


**** stars

  local s=""
  if (`treat'-(1.645*`sd'))*(`treat'+(1.645*`sd'))>0 local s="$^{*\ \ }$"
  if (`treat'-(1.96*`sd'))*(`treat'+(1.96*`sd'))>0 local s="$^{**\ }$"
  if (`treat'-(2.326*`sd'))*(`treat'+(2.326*`sd'))>0 local s="$^{***}$"
  


file write f "&" _tab %5.3f (meanestsgi[1,`i']) "`s'"

								

								
local i=`i'+1
						}
						
file write f "\\" _n
								
			}
			
local i=1

if `row'==2 {   

*** standard errors

foreach var of local vars {

quietly sum sumweightres2_`var' if counteryear==1

local var1=`r(mean)'

quietly sum avgres2_`var' if counterstate==1 [aw=wallall2]

local var2=`r(mean)'

local sd=sqrt((`var1'+`var2')/3)

local low=meanestsgi[1,`i']-(1.96*`sd')
local up=meanestsgi[1,`i']+(1.96*`sd')

file write f "&" _tab "[" %4.3f (`low') ", " %4.3f (`up') "]"

local i=`i'+1
						}
							
file write f "\\" _n

			}
							


						  }
					  
*****
**** Add baseline CI  

*** standard errors

file write f "\hline" _n   _tab

**** Add baseline CI  

*** standard errors

file write f "Bootstrapped Percentiles:" _tab

foreach i of numlist 1/3 {

file write f  "&" _tab "[" %4.3f (confidencegi[`i',1]) ", " %4.3f (confidencegi[`i',2]) "]" _tab 
						}

***

file write f "\\" _n

file write f "Bootstrapped SD:" _tab

foreach i of numlist 1/3 {

local low=meanestsgi[1,`i']-(1.96*confidencegi[`i',3])
local up=meanestsgi[1,`i']+(1.96*confidencegi[`i',3])

file write f  "&" _tab "[" %4.3f (`low') ", " %4.3f (`up') "]" _tab 
						}

***

file write f "\\" _n
file write f "\hline\hline" _n "\multicolumn{4}{l}{\footnotesize The 95\% confidence intervals are displayed in brackets. }" _tab "\\" _n 
file write f "\multicolumn{4}{l}{\footnotesize  \parbox[t]{13cm}{The top panel compares confidence intervals for the key parameters of interest based on our baseline Abadie weights. The bottom panel compares the respective confidence intervals when the Abadie weights also take guaranteed issue and community rating regulations into account. The second row in each panel displays the confidence intervals based on the parametric approach discussed in Section B1. The third row displays the block bootstrapped confidence inrervals of the baseline analysis. The fourth row displays the confidence intervals based on block bootstrapped standard deviations.}}" _tab "\\" _n 
file write f "\multicolumn{4}{l}{\footnotesize $^{*}$ \(p<0.10\), $^{**}$ \(p<0.05\), $^{***}$ \(p<0.01\)}" _tab "\\" _n 
file write f "\end{tabular}" _tab "}"


file close f















