***************************************************************************************************
****** This program conducts the main regression analysis and produces the main regression table 
***************************************************************************************************


clear

set mem 1g

set more off



use Data\Compiled\pointestbaseline.dta

mkmat parall1 parall2 parall3, matrix(meanests)

clear


use Data\Compiled\datasnl-final.dta


*** merge weights

encode state, gen(stateid)

gen statenr=stateid

sort statenr

merge m:1 statenr using Data\Compiled\abadieweights.dta


replace wallall2=1/35 if state=="MA"

replace wallall2=0 if wallall2==.


drop if wallall2==0




gen MA_GI=0 

replace MA_GI=1 if state=="ME" | state=="NY"  | state=="VT" | state=="WA" | state=="MA" 
*replace MA_GI=1 if state=="NJ" | state=="ME" | state=="NY"  | state=="VT" | state=="WA" | state=="MA" 

*** Generaate stateid (for clustering)



**** Normalize year to 2007

gen yearold=year

replace year=year-2007



*** Period Identfiers


gen during=0

replace during=1 if yearold==2006 | yearold==2007



gen after=0

replace after=1 if yearold>2007


**** Interaction Terms

gen MAafter=after*MA

gen MAduring=during*MA


**** Trends


gen MAyear=MA*year


gen after_year=after*year


gen during_year=during*year


gen after_MA_year=after*year*MA


gen during_MA_year=during*year*MA


sort stateid year


**** expand database for bootstrap analysis

save Data\Compiled\bootstrap-snl.dta, replace


sum if year==0

local obs=r(N)


gen weightk=round(10000*wallall2*(1-1/35))

expand weightk

by state yearold, sort: gen counter=_n


gen clusterid=stateid*10000+counter

save Data\Compiled\bootstrap-snl.dta, replace



clear





******************************************************************************
**** Bootstrap Program
******************************************************************************

program define bootreg1, rclass

clear

drop _all

use Data\Compiled\bootstrap-snl.dta

bsample 35 , cluster(clusterid)



*sum MA

***********************************


gen mem_mo_ind_rel=.

levelsof state, local(levels) 

foreach l of local levels {

quietly sum insurance300post if state=="`l'"

local Ihat=r(mean)

disp("`Ihat'")

quietly sum obsnongroup300 if state=="`l'"

local Iobs=r(mean)

disp("`Iobs'")

local Ipost=rbinomial(`Iobs', `Ihat')/`Iobs'

disp("`Ipost'")

quietly sum mem_mo_ind if yearold>2007 & yearold<=2010 & state=="`l'"

local ypostma=r(mean)

replace mem_mo_ind_rel=mem_mo_ind/`ypostma'*`Ipost' if state=="`l'" 

}
****

by stateid, sort: egen endcov_share=max(mem_mo_ind_rel)

replace mem_mo_ind_rel=mem_mo_ind_rel/endcov_share if endcov_share>1.2



* program drop slopes2

*program define slopes2, rclass

*********** derive chnages in enrollment and post-reform enrollment

 local vars "MAafter MAduring MA after during _cons"

 
 ********** Member Months
 
reg mem_mo_ind_rel MAafter MAduring MA after during if yearold<2011, cluster(stateid) 

 foreach var of local vars {

		
local enr`var'=_b[`var']
return scalar enr`var'=`enr`var''	
		
        }


 ********** Claim Expenses
 
gen lgac=log(prov_health_serv_incur_ind_year)

reg lgac MAafter MAduring MA after during if yearold<2011, cluster(stateid) 

 foreach var of local vars {

		
local claim`var'=_b[`var']
return scalar claim`var'=`claim`var''	
		
        }

********** Premiums

gen lgprem=log(prem_per_year_ind)
		 
reg lgprem MAafter MAduring MA after during if yearold<2011 , cluster(stateid)

 foreach var of local vars {

		
local prem`var'=_b[`var']
return scalar prem`var'=`prem`var''	
		
        }


*** post-enrollment

quietly sum mem_mo_ind_rel if yearold<2006 & MA==1
local preenr=r(mean)

*quietly sum lgac if yearold<2006 & MA==1


quietly sum prov_health_serv_incur_ind_year if yearold<2006 & MA==1
local preclaim=r(mean)

*quietly sum lgprem if yearold<2006 & MA==1
quietly sum prem_per_year_ind if yearold<2006 & MA==1
local preprem=r(mean)


sum(MA) 
local MAmean=r(mean)


return scalar Ipre=`preenr'
return scalar Claimpre=`preclaim'
return scalar Prempre=`preprem'
return scalar MAmean=`MAmean'





end


clear

set more off

# delimit ;


simulate premMAafter=r(premMAafter) premMAduring=r(premMAduring) premMA=r(premMA) premafter=r(premafter) premduring=r(premduring) premconstant=r(prem_cons) 
enrMAafter=r(enrMAafter) enrMAduring=r(enrMAduring) enrMA=r(enrMA) enrafter=r(enrafter) enrduring=r(enrduring)  enrconstant=r(enr_cons) 
claimMAafter=r(claimMAafter) claimMAduring=r(claimMAduring) claimMA=r(claimMA) claimafter=r(claimafter) claimduring=r(claimduring) claimconstant=r(claim_cons)
enrpre=r(Ipre) MAmean=r(MAmean) prempre=r(Prempre) claimpre=r(Claimpre) ,  saving(Data\SNL\bootreg1, replace) reps(5000) seed(1111): bootreg1 ;





# delimit cr


**********************************************
*** adjust MAvariables to missing if no MA observation

local MAvarlist "premMAafter premMAduring premMA claimMAafter claimMAduring claimMA enrMAafter enrMAduring enrMA"

foreach var of local MAvarlist {

replace `var'=. if MAmean==0

}
***

program drop bootreg1

label variable claimMAafter "$\gamma^k \ $   MA*After" 
label variable claimMAduring "$\rho_1^k \ $   MA*During" 
label variable claimMA "$\rho_2^k \ $  MA" 
label variable claimafter "$\rho_3^k \ $   After"
label variable claimduring "$\rho_4^k \ $   During"

label variable claimpre "Pre-Reform Value (levels)"
label variable claimconstant "$\rho_{5}^k$   Constant"

****************************************************************************************************************************
***** Create TEX Table
****************************************************************************************************************************


local i=1
local j=1

local vars ""MAafter" "MAduring" "MA" "after" "during" "constant""
local categs ""enr" "prem" "claim"" 

# delimit ;
cap file close f ;
file open f using "${tabout}Data\Compiled\Tables\did-table-boot.tex" , write replace ;
file write f 

"{\begin{tabular}{lccc}" _n
"\hline\hline" _n

"&" _tab "(1)" _tab "&" _tab "(2)" _tab "&" _tab "(3)" _tab "\\" _n
 
"&" _tab "Coverage" _tab "&" _tab "Log Premium" _tab "&" _tab "Log Claim Exp" _tab "\\" _n

"\hline" _n ;

# delimit cr
foreach vari of local vars {


foreach row of numlist 1 2 {



if `row'==1 {

file write f `"`: var label claim`vari''"' _tab 

local j=1

foreach col of local categs {

local varname="`col'"+"`vari'"

**** stars

quietly centile `varname', centile(0.5 2.5 5 95 97.5 99.5)

  local s=""
  if `r(c_3)'*`r(c_4)'>0 local s="$^{*\ \ }$"
  if `r(c_2)'*`r(c_5)'>0 local s="$^{**\ }$"
  if `r(c_1)'*`r(c_6)'>0 local s="$^{***}$"
  
  
  

quietly centile `varname', centile(50)




*sum `col'`vari' 

if "`col'"=="enr"{

file write f "&" _tab %5.3f (meanests[`i',`j']) "`s'"

			}
			
if "`col'"!="enr"{

file write f "&" _tab %5.3f (meanests[`i',`j']) "`s'"

			}	
local j=`j'+1			
									}
								
file write f "\\" _n
								

								
			}

if `row'==2 {   

*** standard errors

local j=1

foreach col of local categs {

local varname="`col'"+"`vari'"

quietly centile `varname', centile(2.5 97.5)


if "`col'"=="enr"{

file write f "&" _tab "[" %4.3f (`r(c_1)') ", " %4.3f (`r(c_2)') "]"

			}
			
if "`col'"!="enr"{

file write f "&" _tab "[" %4.3f (`r(c_1)') ", " %4.3f (`r(c_2)') "]"

			}			

local j=`j'+1

							}
file write f "\\" _n

			}
							


						  }
local i=`i'+1						  
} 

file write f "\hline" _n `"`: var label claimpre'"' _tab 

 

foreach col of local categs {

local varname="`col'"+"pre"

*quietly sum(`varname')
quietly centile `varname', centile(50)
if "`col'"=="enr" {

file write f "&" _tab %5.3f (`r(c_1)') 

}
if "`col'"!="enr"{
file write f "&" _tab %8.2fc (`r(c_1)') 
}
}

file write f "\\" _n "\hline\hline" _n "\multicolumn{4}{l}{\footnotesize The bootsrapped 95\% confidence interval is displayed in brackets.}" _tab "\\" _n 
file write f "\multicolumn{4}{l}{\footnotesize  \parbox[t]{14cm}{Standard errors are block bootstrapped. Abadie weights depend on member month enrollment as well as changes in coverage, relative changes in average costs, and relative changes in premiums between 2004 and 2005. }}" _tab "\\" _n 
file write f "\multicolumn{4}{l}{\footnotesize $^{*}$ \(p<0.10\), $^{**}$ \(p<0.05\), $^{***}$ \(p<0.01\)}" _tab "\\" _n 
file write f "\end{tabular}" _tab "}"


file close f


******* Second table using standard deviations

****************************************************************************************************************************
***** Create TEX Table
****************************************************************************************************************************


local i=1
local j=1

local vars ""MAafter" "MAduring" "MA" "after" "during" "constant""
local categs ""enr" "prem" "claim"" 

# delimit ;
cap file close f ;
file open f using "${tabout}Data\Compiled\Tables\did-table-boot-sd.tex" , write replace ;
file write f 

"{\begin{tabular}{lccc}" _n
"\hline\hline" _n

"&" _tab "(1)" _tab "&" _tab "(2)" _tab "&" _tab "(3)" _tab "\\" _n
 
"&" _tab "Coverage" _tab "&" _tab "Log Premium" _tab "&" _tab "Log Claim Exp" _tab "\\" _n

"\hline" _n ;

# delimit cr
foreach vari of local vars {


foreach row of numlist 1 2 {



if `row'==1 {

file write f `"`: var label claim`vari''"' _tab 

local j=1

foreach col of local categs {

local varname="`col'"+"`vari'"

**** stars

**** standard deviation

quietly sum `varname'

*local standdev=`r(sd)'

local lowonest=meanests[`i',`j']-1.645*`r(sd)'
local uponest=meanests[`i',`j']+1.645*`r(sd)'

local lowtwost=meanests[`i',`j']-1.96*`r(sd)'
local uptwost=meanests[`i',`j']+1.96*`r(sd)'

local lowthreest=meanests[`i',`j']-2.576*`r(sd)'
local upthreest=meanests[`i',`j']+2.576*`r(sd)'

  local s=""
  if `lowonest'*`uponest'>0 local s="$^{*\ \ }$"
  if `lowtwost'*`uptwost'>0 local s="$^{**\ }$"
  if `lowthreest'*`upthreest'>0 local s="$^{***}$"
  
 

*sum `col'`vari' 

if "`col'"=="enr"{

file write f "&" _tab %5.3f (meanests[`i',`j']) "`s'"

			}
			
if "`col'"!="enr"{

file write f "&" _tab %5.3f (meanests[`i',`j']) "`s'"

			}	
local j=`j'+1			
									}
								
file write f "\\" _n
								

								
			}

if `row'==2 {   

*** standard errors

local j=1

foreach col of local categs {

local varname="`col'"+"`vari'"

quietly sum `varname'

local lowtwost=meanests[`i',`j']-1.96*`r(sd)'
local uptwost=meanests[`i',`j']+1.96*`r(sd)'


if "`col'"=="enr"{

file write f "&" _tab "[" %4.3f (`lowtwost') ", " %4.3f (`uptwost') "]"

			}
			
if "`col'"!="enr"{

file write f "&" _tab "[" %4.3f (`lowtwost') ", " %4.3f (`uptwost') "]"

			}			

local j=`j'+1

							}
file write f "\\" _n

			}
							


						  }
local i=`i'+1						  
} 

file write f "\hline" _n `"`: var label claimpre'"' _tab 

 

foreach col of local categs {

local varname="`col'"+"pre"

*quietly sum(`varname')
quietly centile `varname', centile(50)
if "`col'"=="enr" {

file write f "&" _tab %5.3f (`r(c_1)') 

}
if "`col'"!="enr"{
file write f "&" _tab %8.2fc (`r(c_1)') 
}
}

file write f "\\" _n "\hline\hline" _n "\multicolumn{4}{l}{\footnotesize The bootsrapped 95\% confidence interval is displayed in brackets.}" _tab "\\" _n 
file write f "\multicolumn{4}{l}{\footnotesize  \parbox[t]{14cm}{Standard errors are block boostrapped. Abadie weights depend on member month enrollment as well as changes in coverage, relative changes in average costs, and relative changes in premiums between 2004 and 2005. }}" _tab "\\" _n 
file write f "\multicolumn{4}{l}{\footnotesize $^{*}$ \(p<0.10\), $^{**}$ \(p<0.05\), $^{***}$ \(p<0.01\)}" _tab "\\" _n 
file write f "\end{tabular}" _tab "}"


file close f


*** store main confidence intervals and sd

local keyvars ""enrMAafter" "premMAafter" "claimMAafter"" 

local i=1

foreach var of local keyvars {

quietly centile `var', centile(2.5 97.5)

matrix con1= round(`r(c_1)',0.001)
matrix con2= round(`r(c_2)',0.001)


quietly sum `var'

matrix con3= `r(sd)'

matrix bothcon`i'=con1,con2,con3

local i=`i'+1

}

***



matrix confinal=bothcon1\bothcon2\bothcon3

clear

svmat confinal

save Data\Compiled\CI_main.dta, replace

clear





