*******************************************************************************
****** This do file prepares the DID figures for the baseline analysis
*******************************************************************************


clear all

set more off

use Data\Compiled\datasnl-final.dta


encode state, gen(stateid)


gen mem_mo_ind_rel=.

**** For all States

levelsof state, local(levels) 

foreach l of local levels {

quietly sum mem_mo_ind if year>2007 & year<=2010 & state=="`l'"

local ypostma=r(mean)

replace mem_mo_ind_rel=mem_mo_ind/`ypostma'*insurance300post if state=="`l'" 


}
***

**** Adjust Other States if estimate exceeds 120%


by stateid, sort: egen endcov_share=max(mem_mo_ind_rel)

replace mem_mo_ind_rel=mem_mo_ind_rel/endcov_share if endcov_share>1.2
****




*** merge abadie weights


gen statenr=stateid

sort statenr

merge m:1 statenr using Data\Compiled\abadieweights.dta


replace wallall2=1/35 if state=="MA"


replace wallall2=0 if wallall2==.



drop if wallall2==0




gen MA_GI=0 

replace MA_GI=1 if state=="ME" | state=="NY"  | state=="VT" | state=="WA" | state=="MA" 


*** Generaate stateid (for clustering)



**** Normalize year to 2007

gen yearold=year





*** Period Identfiers


gen during=0

replace during=1 if yearold==2006 | yearold==2007



gen after=0

replace after=1 if yearold>2007


**** Interaction Terms

gen MAafter=after*MA

gen MAduring=during*MA


**** Trends


gen MAyear=MA*year


gen after_year=after*year


gen during_year=during*year


gen after_MA_year=after*year*MA


gen during_MA_year=during*year*MA


sort stateid year

**** Other States

quietly tab year, gen(yearfe)


quietly tab MAyear, gen(MAyearfe)


replace year=year-2007


***** regressions

gen lgprem=log(prem_per_year_ind)

gen lgac=log(prov_health_serv_incur_ind_year)


*** normalize by 2004 levels


*** premiums
gen lgprem_pre=lgprem if yearold==2004
by state, sort: egen  lgprem_pre_adj=max(lgprem_pre)

replace lgprem=lgprem-lgprem_pre_adj

*** claims
gen lgac_pre=lgac if yearold==2004
by state, sort: egen  lgac_pre_adj=max(lgac_pre)

replace lgac=lgac-lgac_pre_adj


*** coverage 
gen mem_mo_ind_rel_pre=mem_mo_ind_rel if yearold==2004
by state, sort: egen  mem_mo_ind_rel_pre_adj=max(mem_mo_ind_rel_pre)

replace mem_mo_ind_rel=mem_mo_ind_rel-mem_mo_ind_rel_pre_adj



*** regressions

reg lgprem yearfe2-yearfe8 MAyearfe3-MAyearfe9 if year<=2011  [aweight=wallall2] , noconstant

estimates save Data\Compiled\premind, replace

reg mem_mo_ind_rel yearfe2-yearfe8 MAyearfe3-MAyearfe9  if year<=2011 [aweight=wallall2], noconstant

estimates save Data\Compiled\memind, replace

reg lgac yearfe2-yearfe8 MAyearfe3-MAyearfe9 if year<=2011 [aweight=wallall2], noconstant

estimates save Data\Compiled\claimind, replace


****** Get estimates


clear

estimates use Data\Compiled\premind

matrix define premind=e(b)
matrix premind_nma=[0,premind[1,1..7]]'
matrix premind_ma=[0,premind[1,8..14]]'

*** adjust pre-levels
*matrix premind_pre=[premind[1,1]]'

svmat premind_nma
svmat premind_ma
*svmat premind_pre

*gen premind_pre=max(premind_pre)


rename premind_nma1 premind_nma
rename premind_ma1 premind_ma

gen premind_ma_final=premind_nma+premind_ma

matrix drop premind premind_ma premind_nma

estimates use Data\Compiled\memind

matrix define memind=e(b)
matrix memind_nma=[0,memind[1,1..7]]'
matrix memind_ma=[0,memind[1,8..14]]'

svmat memind_nma
svmat memind_ma

matrix drop memind memind_ma memind_nma

rename memind_nma1 memind_nma 
rename memind_ma1 memind_ma

gen memind_ma_final=memind_nma+memind_ma

estimates use Data\Compiled\claimind

matrix define claimind=e(b)
matrix claimind_nma=[0,claimind[1,1..7]]'
matrix claimind_ma=[0,claimind[1,8..14]]'

svmat claimind_nma
svmat claimind_ma

matrix drop claimind claimind_ma claimind_nma

rename claimind_nma1 claimind_nma 
rename claimind_ma1 claimind_ma

gen claimind_ma_final=claimind_nma+claimind_ma


gen year=_n-4

local varlist "premind claimind memind"
local titlelist ""Log Annual Premiums" "Log Annual Average Claim Expenditures" "Enrollment in Percent""
local yaxistitlelist ""Log Annual Premium" "Log Annual Claim Expenditures per Person" "Health Insurance Coverage in Population""
local graphnamelist ""Data\Compiled\Figures\premind" "Data\Compiled\Figures\claimind" "Data\Compiled\Figures\memind""

local i=1


foreach var of local varlist {

local title: word `i' of `titlelist'
local yaxistitle: word `i' of `yaxistitlelist'
local graphname: word `i' of `graphnamelist'


*estimates use `var'_pred

*matrix define `var'_pred=e(b)

*gen `var'_pred_ma_pre=.
*gen `var'_pred_nma_pre=.
*gen `var'_pred_ma_post=.
*gen `var'_pred_nma_post=.
*replace `var'_pred_ma_pre=`var'_pred[1,2]+`var'_pred[1,12]+(`var'_pred[1,3]+`var'_pred[1,4])*year
*replace `var'_pred_nma_pre=`var'_pred[1,12]+(`var'_pred[1,3])*year

*replace `var'_pred_ma_post=`var'_pred[1,1]+`var'_pred[1,2]+`var'_pred[1,5]+`var'_pred[1,12]+(`var'_pred[1,3]+`var'_pred[1,4])*year+(`var'_pred[1,6]+`var'_pred[1,7])*year
*replace `var'_pred_nma_post=`var'_pred[1,5]+`var'_pred[1,12]+(`var'_pred[1,3])*year+(`var'_pred[1,6])*year


*matrix drop `var'_pred

    scatter `var'_nma `var'_ma_final year, connect(l l) ///	
	xlabel(-3 "2004"  -1 "2006" 1 "2008" 3 "2010") ///
	msize(small small) ///
	lpattern(solid dash) ///
	lwidth(medthick medthick) ///
	lcolor(gs0 blue) ///
	mcolor(gs0 blue) ///
	msymbol(O O) ///
	xtitle("Year") ///
	ytitle(`yaxistitle') ///
	xline(-1) xline(0) ///
	graphregion(color(white)) ///
	legend(rows(1) label(1 Non-MA)  label(2 MA) ) ///
    saving(`graphname'.gph, replace)
    local i=`i'+1
}
*******************

graph combine Data\Compiled\Figures\premind.gph  , xsize(11)  ysize(7.5) graphregion(color(white)) 
graph export Data\Compiled\Figures\premind.ps, replace logo(off) orientation(landscape) lmargin(0) tmargin(0.5)
capture ! ps2pdf Data\Compiled\Figures\premind.ps Data\Compiled\Figures\premind.pdf

graph combine Data\Compiled\Figures\claimind.gph  , xsize(11)  ysize(7.5) graphregion(color(white)) 
graph export Data\Compiled\Figures\claimind.ps, replace logo(off) orientation(landscape) lmargin(0) tmargin(0.5)
capture ! ps2pdf Data\Compiled\Figures\claimind.ps Data\Compiled\Figures\claimind.pdf

graph combine Data\Compiled\Figures\memind.gph  , xsize(11)  ysize(7.5) graphregion(color(white)) 
graph export Data\Compiled\Figures\memind.ps, replace logo(off) orientation(landscape) lmargin(0) tmargin(0.5)
capture ! ps2pdf Data\Compiled\Figures\memind.ps Data\Compiled\Figures\memind.pdf
