***********************************************************************
*** Prepare Data Sets
***********************************************************************


*** This file discusses and conducts the preparation of relevant datasets that are used 
*** in the emprical analysis




clear

set mem 1g

set more off

*log using preparedata.txt, replace


********************************************************
***** NHIS data
********************************************************


*** Run separate do file on raw NHIS data: 

*** to be discussed !!!!!!!!!!!!!!!

*** Using the sumamry files from the NHIS

insheet using Data\NHIS\state-period-mean.csv

*** keep post reform coverage information and state identifier

keep insurance300post insurance150post state300

drop if state300==.

sort state300

save Data\Compiled\state-post-coverage-mean.dta, replace

clear

**** Create Standard deviation of coverage estimates

insheet using Data\NHIS\observations-all.csv

*** post-reform years

keep if year>2007

collapse (sum) obsnongroup150 obsnongroup300, by(state)

rename state state300

sort state300

merge state300 using Data\Compiled\state-post-coverage-mean.dta

keep if _merge==3

drop _merge

**** Gen std:

gen insurance300post_std=sqrt(insurance300post*(1-insurance300post)/obsnongroup300)

gen insurance150post_std=sqrt(insurance150post*(1-insurance150post)/obsnongroup150)

*keep state300 insurance300post insurance150post insurance300post_std insurance150post_std

sort state300

save Data\Compiled\state-post-coverage-mean.dta, replace

clear

*** Merge State name

clear

insheet using Data\NHIS\State-Match.csv

drop if state300==.

sort state300

merge state300 using Data\Compiled\state-post-coverage-mean.dta

keep if _merge==3

drop _merge state300

sort state

save Data\Compiled\state-post-coverage-mean.dta, replace


clear


***********************************
*** Medical CPI year 04-11 (normalized to 2012)
***********************************

insheet using Data\medcpi04-11.csv

sort year

*drop cpi_n12

*rename cpiuall_n12 cpi_n12

save Data\Compiled\medcpi04-11.dta, replace

clear



******************************************
***** SNL Data
******************************************

*** raw data: see raw data discussion for details



*** Hmo-information (robustness check section)

*** data contains HMO name identifier (convert into dta)


insheet using Data\SNL\hmo-info-plan.csv

sort compname state

drop if compname==compname[_n-1] & state==state[_n-1] 

sort compname state

save Data\Compiled\hmo-info-plan.dta, replace

clear

******************************************************************************************
***** Main dataset
******************************************************************************************


use Data\SNL\datasnl.dta

sort compname year state v3

drop if compname==compname[_n-1] & state==state[_n-1] & year==year[_n-1] & v3=="Historical" 

*drop if v3=="Historical"

sort year

merge year using Data\Compiled\medcpi04-11.dta

drop _merge

sort compname state

merge m:1 compname state using Data\Compiled\hmo-info-plan.dta

drop _merge

*********************************************
***** Drop Guam
**********************************************

drop if state=="GU"


**************************************************************************************
**** deflate relevant measures: ALL in 2012 Dollars
**************************************************************************************


replace direct_prem_grp=direct_prem_grp*cpi_n12
replace direct_prem_ind=direct_prem_ind*cpi_n12
replace claimcae=claimcae*cpi_n12
replace adm=adm*cpi_n12

replace prov_health_serv_incur_grp=prov_health_serv_incur_grp*cpi_n12
replace prov_health_serv_incur_ind=prov_health_serv_incur_ind*cpi_n12



********************************************
*** Revise Outlier observation in NY
********************************************

sort compname state year

gen premium_per_mm_ind=direct_prem_ind/mem_mo_ind
gen premium_per_mm_grp=direct_prem_grp/mem_mo_grp
 
*gen  mem_mo_ind_temp=direct_prem_ind/premium_per_mm_ind[_n-1] if compname=="Empire HealthChoice HMO Inc." & state=="NY" & year==2008
*gen  mem_mo_grp_temp=direct_prem_grp/premium_per_mm_grp[_n-1] if compname=="Empire HealthChoice HMO Inc." & state=="NY" & year==2008
replace mem_mo_ind=direct_prem_ind/premium_per_mm_ind[_n-1] if compname=="Empire HealthChoice HMO Inc." & state=="NY" & year==2008
replace mem_mo_grp=direct_prem_grp/premium_per_mm_grp[_n-1] if compname=="Empire HealthChoice HMO Inc." & state=="NY" & year==2008


****************************************************************
*** Premiums and Average Costs per year in dollars (beforhand reported in $1000)
****************************************************************


gen prem_per_year_grp= direct_prem_grp/mem_mo_grp*12*1000

gen prem_per_year_ind= direct_prem_ind/mem_mo_ind*12*1000

gen claimcae_per_year= claimcae/(mem_mo_grp+mem_mo_ind)*12*1000

gen adm_per_year= adm/(mem_mo_grp+mem_mo_ind)*12*1000

gen prov_health_serv_incur_grp_year=prov_health_serv_incur_grp/(mem_mo_grp)*12*1000

gen prov_health_serv_incur_ind_year=prov_health_serv_incur_ind/(mem_mo_ind)*12*1000



********************************************************************************
**** Adjust Premium Revenues and Average Costs
********************************************************************************

replace direct_prem_ind=. if prem_per_year_ind<=50 | prem_per_year_ind>20000 | prov_health_serv_incur_ind_year<=50 | prov_health_serv_incur_ind_year>20000 | mem_mo_ind==.
replace prov_health_serv_incur_ind=. if prem_per_year_ind<=50 | prem_per_year_ind>20000 | prov_health_serv_incur_ind_year<=50 | prov_health_serv_incur_ind_year>20000  | mem_mo_ind==.
replace mem_mo_ind=. if prem_per_year_ind<=50 | prem_per_year_ind>20000 | prov_health_serv_incur_ind_year<=50 | prov_health_serv_incur_ind_year>20000 | direct_prem_ind==. | prov_health_serv_incur_ind==.

replace direct_prem_grp=. if prem_per_year_grp<=50 | prem_per_year_grp>20000 | prov_health_serv_incur_grp_year<=50 | prov_health_serv_incur_grp_year>20000 
replace prov_health_serv_incur_grp=. if prem_per_year_grp<=50 | prem_per_year_grp>20000 | prov_health_serv_incur_grp_year<=50 | prov_health_serv_incur_grp_year>20000 
replace mem_mo_grp=. if prem_per_year_grp<=50 | prem_per_year_grp>20000 | prov_health_serv_incur_grp_year<=50 | prov_health_serv_incur_grp_year>20000 



***** Drop Commonwealth Care providers ni Massachusetts

drop if (compname=="Neighborhood Health Plan Inc." & state=="MA") | (compname=="Boston Med Center Health Plan" & state=="MA") | (compname=="Fallon Community Hlth Plan Inc" & state=="MA") | (compname=="Network Health LLC" & state=="MA")


**** Drop outlier in WA

drop if (compname=="Community Health Plan of WA" & state=="WA") 




***** Sum expenditures, enrollment, and claim expenditures at the state-year level 


gen hmo_mem_mo_ind=hmo*mem_mo_ind

collapse (sum) mem_mo_grp mem_mo_ind direct_prem_grp direct_prem_ind prov_health_serv_incur_grp prov_health_serv_incur_ind mem_phy_enc_ind mem_hosp_days_ind mem_amb_enc_ind (sum) hmo_mem_mo_ind, by(state year) 


gen hmo_share=hmo_mem_mo_ind/mem_mo_ind

gen prem_per_year_grp= direct_prem_grp/mem_mo_grp*12*1000
gen prem_per_year_ind= direct_prem_ind/mem_mo_ind*12*1000

gen prov_health_serv_incur_grp_year=prov_health_serv_incur_grp/(mem_mo_grp)*12*1000
gen prov_health_serv_incur_ind_year=prov_health_serv_incur_ind/(mem_mo_ind)*12*1000


gen mem_phy_enc_ind_rel=mem_phy_enc_ind/mem_mo_ind
gen mem_hosp_days_ind_rel=mem_hosp_days_ind/mem_mo_ind
gen mem_amb_enc_ind_rel=mem_amb_enc_ind/mem_mo_ind
  

   

**** MA identifier

gen MA=0

replace MA=1 if state=="MA"

***** Merge Post-Reform Coverage Information:

sort state

merge state using Data\Compiled\state-post-coverage-mean.dta

drop if _merge==2

drop _merge


save Data\Compiled\datasnl-final.dta, replace



clear



*log close
