*******************************************************************************
****** This file considers robustness of our findings with repect to plan generosity using the SNL data. 
****** These findings are referenced in the robustness check section of the paper
*******************************************************************************


clear all

use Data\Compiled\datasnl-final.dta


**** Guaranteed Issue identifier

gen MA_GI=0 

replace MA_GI=1 if state=="ME" | state=="NY"  | state=="VT" | state=="WA" | state=="MA" 


*** Generaate stateid (for clustering)

encode state, gen(stateid)

gen statenr=stateid

sort statenr

merge m:1 statenr using Data\Compiled\abadieweights.dta


replace wallall2=1/35 if state=="MA"



replace wallall2=0 if wallall2==.



drop if wallall2==0



gen yearold=year

replace year=year-2007



*** Period Identfiers


gen during=0

replace during=1 if yearold==2006 | yearold==2007



gen after=0

replace after=1 if yearold>2007


**** Interaction Terms

gen MAafter=after*MA

gen MAduring=during*MA

gen mem_mo_ind_rel=.

levelsof state, local(levels) 


foreach l of local levels {

quietly sum mem_mo_ind if yearold>2007 & yearold<=2010 & state=="`l'"

local ypostma=r(mean)

replace mem_mo_ind_rel=mem_mo_ind/`ypostma'*insurance300post if state=="`l'" 


}
**

by stateid, sort: egen endcov_share=max(mem_mo_ind_rel)

replace mem_mo_ind_rel=mem_mo_ind_rel/endcov_share if endcov_share>1.2




reg mem_mo_ind_rel MAafter MAduring MA after during hmo_share [aw=wallall2] if yearold<2011

gen lgac=log(prov_health_serv_incur_ind_year)

gen lgprem=log(prem_per_year_ind)


***************************************************
*** General Trends in HMO_shares
*************************************************


table yearold if MA==1, c(mean hmo_share) 






**** Point estimates in first row of the following regressions are referenced in the paper
**** Standard errors are not contructed


reg lgac MAafter MAduring MA after during hmo_share [aw=wallall2] if yearold<2011


reg lgprem MAafter MAduring MA after during hmo_share [aw=wallall2] if yearold<2011


**** we note that hmo_share is missing in 2004 (which appears to be the case because BCBS MA reports all enrollees in the non-HMO plan in 2004
**** We show that this doesn't drive the results by simply replacing the 2004 value by the 2005 value for MA

quietly sum hmo_share if yearold==2005 & MA==1

replace hmo_share=`r(mean)' if MA==1 & yearold==2004 


*** we rerun the regressions, which deliver very similar estimates

reg lgac MAafter MAduring MA after during hmo_share [aw=wallall2] if yearold<2011


reg lgprem MAafter MAduring MA after during hmo_share [aw=wallall2] if yearold<2011

**** with updated trends

table yearold if MA==1, c(mean hmo_share)


